@@ -1,4 +1,4 @@
-# $Id: install.py 1147 2014-11-28 14:14:45Z mwall $
+# $Id: install.py 1176 2014-12-07 16:50:52Z mwall $
 # installer for the forecast extension
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.0",
+            version="3.0.1",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -41,9 +41,7 @@ class ForecastInstaller(ExtensionInstaller):
                 'StdReport': {
                     'forecast': {
                         'skin': 'forecast',
-                        'HTML_ROOT': 'forecast',
-                        'Extras': {
-                            'forecast_table':'INST_SKIN_ROOT/forecast/forecast_table.inc'}}}},
+                        'HTML_ROOT': 'forecast'}}},
             files=[('bin/user',
                     ['bin/user/forecast.py']),
                    ('skins/forecast',
